searchData={"items":[{"type":"module","title":"TestLlm","doc":"# TestLlm\n\nTestLlm provides helpers to easily stub LLM responses with [Req.Test](https://hexdocs.pm/req/Req.Test.html) or with [Bypass](https://hex.pm/packages/bypass)\n\nWhen building with LLM's I find it easier to test with real outputs from prompts. TestLlm enables easy stubbing of the request by automatically generating and saving the response in the configured fixtures directory on the first request then on subsequent requests the saved response will be used. \n\nTo rerun the request and update the saved response pass rerun: true as an opt to the expect_response or expect_stream_response function.\n\nTestLlm supports streamed and unstreamed requests. It is recommended to use Bypass for streamed requests as Req.Test does not support chunking back the response and will just return the full response after all chunks are received.","ref":"TestLlm.html"},{"type":"module","title":"Installation - TestLlm","doc":"```elixir\ndef deps do\n  [\n    {:test_llm, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"TestLlm.html#module-installation"},{"type":"module","title":"Setup the fixtures folder - TestLlm","doc":"In your test_helper.exs\n\n```elixir\nApplication.put_env(\n  :test_llm,\n  :base_dir,\n  Path.join([__DIR__, \"support\", \"fixtures\", \"llm\"])\n)\n```","ref":"TestLlm.html#module-setup-the-fixtures-folder"},{"type":"module","title":"Examples - TestLlm","doc":"**Req**\n\n  ```elixir\n  TestLlm.Req.expect_response(key: \"test-1\", model: \"o3-mini-2025-01-31\")\n  Req.post!(\"https://llm.path\", plug: TestLlmReq.plug())\n\n\n  # with a rerun\n  TestLlm.Req.expect_stream_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", rerun: true)\n  Req.post!(\"https://llm.base/llm/model\", plug: TestLlmReq.plug())\n  ```\n\n  **Bypass**\n\n  ```elixir\n  bypass = Bypass.open()\n  bypass_base_url = TestLlm.Bypass.base_url(bypass)\n  llm_base_url = \"https://llm.base\"\n\n  TestLlm.Bypass.expect_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", bypass: bypass, original_base_url: llm_base_url)\n  Req.post!(\"#{bypass_base_url}/llm/model\")\n\n  # With a rerun\n  TestLlm.Bypass.expect_stream_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", bypass: bypass, original_base_url: llm_base_url, rerun: true)\n  Req.post!(\"#{bypass_base_url}/llm/model\")\n\n  # With multiple expects this will expect each one in order\n  TestLlm.Bypass.expect_stream_response([\n    [\n      key: \"stream-1\",\n      bypass: bypass,\n      original_base_url: llm_base_url\n    ],\n    [\n      key: \"stream-2\",\n      bypass: bypass,\n      original_base_url: llm_base_url\n    ],\n  ])\n  ```","ref":"TestLlm.html#module-examples"},{"type":"module","title":"Run tests with responses tracking - TestLlm","doc":"","ref":"TestLlm.html#module-run-tests-with-responses-tracking"},{"type":"module","title":"Shows the responses used after a test suits run - TestLlm","doc":"Useful for showing which response fixtures were used during the test run.\n\n```sh\nTEST_LLM_SHOW_RESPONSES_HITS=1 mix test \n```","ref":"TestLlm.html#module-shows-the-responses-used-after-a-test-suits-run"},{"type":"module","title":"Shows the unused responses after a test suits run - TestLlm","doc":"```sh\nTEST_LLM_SHOW_UNUSED_RESPONSES=1 mix test\n```","ref":"TestLlm.html#module-shows-the-unused-responses-after-a-test-suits-run"},{"type":"module","title":"Removes the unused responses after a test suits run - TestLlm","doc":"Useful for cleaning up unused response fixtures which are no longer used.\n\n```sh\nTEST_LLM_SHOW_UNUSED_RESPONSES=1 mix test test \n```","ref":"TestLlm.html#module-removes-the-unused-responses-after-a-test-suits-run"},{"type":"function","title":"TestLlm.fetch_response/2","doc":"","ref":"TestLlm.html#fetch_response/2"},{"type":"function","title":"TestLlm.fetch_stream_response/2","doc":"","ref":"TestLlm.html#fetch_stream_response/2"},{"type":"function","title":"TestLlm.model_resp/2","doc":"","ref":"TestLlm.html#model_resp/2"},{"type":"function","title":"TestLlm.model_resp_as_json/2","doc":"","ref":"TestLlm.html#model_resp_as_json/2"},{"type":"function","title":"TestLlm.model_resps_as_json/2","doc":"","ref":"TestLlm.html#model_resps_as_json/2"},{"type":"module","title":"TestLlm.Bypass","doc":"Stubing LLM responses with Bypass","ref":"TestLlm.Bypass.html"},{"type":"function","title":"TestLlm.Bypass.base_url/1","doc":"","ref":"TestLlm.Bypass.html#base_url/1"},{"type":"function","title":"TestLlm.Bypass.expect_response/1","doc":"Stubs the expected response.","ref":"TestLlm.Bypass.html#expect_response/1"},{"type":"function","title":"Options - TestLlm.Bypass.expect_response/1","doc":"Basic request options:\n\n  * `:key` - stub reponse file name transformed to slug.\n  * `:original_base_url` - The base url for the call to the LLM.\n  * `:bypass` - The bypass connection.\n  * `:rerun` - should the request be rerun and saved, defaults to `:false`.\n  * `:model` - should the request be rerun and saved, defaults to `the name of the model from the request if available`.","ref":"TestLlm.Bypass.html#expect_response/1-options"},{"type":"function","title":"TestLlm.Bypass.expect_stream_response/1","doc":"Stubs the expected stream response.","ref":"TestLlm.Bypass.html#expect_stream_response/1"},{"type":"function","title":"Options - TestLlm.Bypass.expect_stream_response/1","doc":"Basic request options:\n\n  * `:key` - stub reponse file name transformed to slug.\n  * `:original_base_url` - The base url for the call to the LLM.\n  * `:bypass` - The bypass connection.\n  * `:rerun` - should the request be rerun and saved, defaults to `:false`.\n  * `:model` - should the request be rerun and saved, defaults to `the name of the model from the request if available`.","ref":"TestLlm.Bypass.html#expect_stream_response/1-options"},{"type":"function","title":"TestLlm.Bypass.get_stream_response_chunks/2","doc":"","ref":"TestLlm.Bypass.html#get_stream_response_chunks/2"},{"type":"function","title":"TestLlm.Bypass.open/0","doc":"","ref":"TestLlm.Bypass.html#open/0"},{"type":"function","title":"TestLlm.Bypass.send_resp/2","doc":"","ref":"TestLlm.Bypass.html#send_resp/2"},{"type":"module","title":"TestLlm.Helpers","doc":"","ref":"TestLlm.Helpers.html"},{"type":"function","title":"TestLlm.Helpers.base_dir/0","doc":"","ref":"TestLlm.Helpers.html#base_dir/0"},{"type":"function","title":"TestLlm.Helpers.extract_model_name/1","doc":"","ref":"TestLlm.Helpers.html#extract_model_name/1"},{"type":"function","title":"TestLlm.Helpers.file_name/1","doc":"","ref":"TestLlm.Helpers.html#file_name/1"},{"type":"function","title":"TestLlm.Helpers.file_path/2","doc":"","ref":"TestLlm.Helpers.html#file_path/2"},{"type":"function","title":"TestLlm.Helpers.folder_name/1","doc":"","ref":"TestLlm.Helpers.html#folder_name/1"},{"type":"function","title":"TestLlm.Helpers.replace_model_resp/3","doc":"","ref":"TestLlm.Helpers.html#replace_model_resp/3"},{"type":"function","title":"TestLlm.Helpers.stream_file_name/1","doc":"","ref":"TestLlm.Helpers.html#stream_file_name/1"},{"type":"function","title":"TestLlm.Helpers.stream_file_path/2","doc":"","ref":"TestLlm.Helpers.html#stream_file_path/2"},{"type":"function","title":"TestLlm.Helpers.to_file_path/2","doc":"","ref":"TestLlm.Helpers.html#to_file_path/2"},{"type":"function","title":"TestLlm.Helpers.to_folder_path/2","doc":"","ref":"TestLlm.Helpers.html#to_folder_path/2"},{"type":"function","title":"TestLlm.Helpers.write_resp/2","doc":"","ref":"TestLlm.Helpers.html#write_resp/2"},{"type":"module","title":"TestLlm.ProcessHelper","doc":"","ref":"TestLlm.ProcessHelper.html"},{"type":"function","title":"TestLlm.ProcessHelper.assert_mailbox_empty/1","doc":"","ref":"TestLlm.ProcessHelper.html#assert_mailbox_empty/1"},{"type":"function","title":"TestLlm.ProcessHelper.format_mailbox/2","doc":"","ref":"TestLlm.ProcessHelper.html#format_mailbox/2"},{"type":"function","title":"TestLlm.ProcessHelper.last_ten_mailbox_messages/0","doc":"","ref":"TestLlm.ProcessHelper.html#last_ten_mailbox_messages/0"},{"type":"function","title":"TestLlm.ProcessHelper.mailbox_messages/0","doc":"","ref":"TestLlm.ProcessHelper.html#mailbox_messages/0"},{"type":"module","title":"TestLlm.Req","doc":"Stubing LLM responses with Req.Test","ref":"TestLlm.Req.html"},{"type":"function","title":"TestLlm.Req.expect_response/1","doc":"Stubs the expected response.","ref":"TestLlm.Req.html#expect_response/1"},{"type":"function","title":"Options - TestLlm.Req.expect_response/1","doc":"Basic request options:\n\n  * `:key` - stub reponse file name transformed to slug.\n  * `:rerun` - should the request be rerun and saved, defaults to `:false`.\n  * `:model` - should the request be rerun and saved, defaults to `the name of the model from the request if available`.","ref":"TestLlm.Req.html#expect_response/1-options"},{"type":"function","title":"TestLlm.Req.expect_stream_response/1","doc":"Stubs the expected stream response.","ref":"TestLlm.Req.html#expect_stream_response/1"},{"type":"function","title":"Options - TestLlm.Req.expect_stream_response/1","doc":"Basic request options:\n\n  * `:key` - stub reponse file name transformed to slug.\n  * `:rerun` - should the request be rerun and saved, defaults to `:false`.\n  * `:model` - should the request be rerun and saved, defaults to `the name of the model from the request if available`.","ref":"TestLlm.Req.html#expect_stream_response/1-options"},{"type":"function","title":"TestLlm.Req.plug/0","doc":"Returns the req test plug to use pass to req as a plug option.","ref":"TestLlm.Req.html#plug/0"},{"type":"module","title":"TestLlm.ResponsesTracker","doc":"","ref":"TestLlm.ResponsesTracker.html"},{"type":"function","title":"TestLlm.ResponsesTracker.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"TestLlm.ResponsesTracker.html#child_spec/1"},{"type":"function","title":"TestLlm.ResponsesTracker.hit/1","doc":"","ref":"TestLlm.ResponsesTracker.html#hit/1"},{"type":"function","title":"TestLlm.ResponsesTracker.hits/0","doc":"","ref":"TestLlm.ResponsesTracker.html#hits/0"},{"type":"function","title":"TestLlm.ResponsesTracker.maybe_start/0","doc":"","ref":"TestLlm.ResponsesTracker.html#maybe_start/0"},{"type":"type","title":"TestLlm.ResponsesTracker.t/0","doc":"","ref":"TestLlm.ResponsesTracker.html#t:t/0"},{"type":"extras","title":"TestLlm","doc":"# TestLlm\n\nTestLlm provides helpers to easily stub LLM responses with [Req.Test](https://hexdocs.pm/req/Req.Test.html) or with [Bypass](https://hex.pm/packages/bypass)\n\nWhen building with LLM's I find it easier to test with real outputs from prompts. TestLlm enables easy stubbing of the request by automatically generating and saving the response in the configured fixtures directory on the first request then on subsequent requests the saved response will be used. \n\nTo rerun the request and update the saved response pass rerun: true as an opt to the expect_response or expect_stream_response function.\n\nTestLlm supports streamed and unstreamed requests. It is recommended to use Bypass for streamed requests as Req.Test does not support chunking back the response and will just return the full response after all chunks are received.","ref":"readme.html"},{"type":"extras","title":"Installation - TestLlm","doc":"```elixir\ndef deps do\n  [\n    {:test_llm, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Setup the fixtures folder - TestLlm","doc":"In your test_helper.exs\n\n```elixir\nApplication.put_env(\n  :test_llm,\n  :base_dir,\n  Path.join([__DIR__, \"support\", \"fixtures\", \"llm\"])\n)\n```","ref":"readme.html#setup-the-fixtures-folder"},{"type":"extras","title":"Examples - TestLlm","doc":"**Req**\n\n  ```elixir\n  TestLlm.Req.expect_response(key: \"test-1\", model: \"o3-mini-2025-01-31\")\n  Req.post!(\"https://llm.path\", plug: TestLlmReq.plug())\n\n\n  # with a rerun\n  TestLlm.Req.expect_stream_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", rerun: true)\n  Req.post!(\"https://llm.base/llm/model\", plug: TestLlmReq.plug())\n  ```\n\n  **Bypass**\n\n  ```elixir\n  bypass = Bypass.open()\n  bypass_base_url = TestLlm.Bypass.base_url(bypass)\n  llm_base_url = \"https://llm.base\"\n\n  TestLlm.Bypass.expect_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", bypass: bypass, original_base_url: llm_base_url)\n  Req.post!(\"#{bypass_base_url}/llm/model\")\n\n  # With a rerun\n  TestLlm.Bypass.expect_stream_response(key: \"test-1\", model: \"o3-mini-2025-01-31\", bypass: bypass, original_base_url: llm_base_url, rerun: true)\n  Req.post!(\"#{bypass_base_url}/llm/model\")\n\n  # With multiple expects this will expect each one in order\n  TestLlm.Bypass.expect_stream_response([\n    [\n      key: \"stream-1\",\n      bypass: bypass,\n      original_base_url: llm_base_url\n    ],\n    [\n      key: \"stream-2\",\n      bypass: bypass,\n      original_base_url: llm_base_url\n    ],\n  ])\n  ```","ref":"readme.html#examples"},{"type":"extras","title":"Run tests with responses tracking - TestLlm","doc":"","ref":"readme.html#run-tests-with-responses-tracking"},{"type":"extras","title":"Shows the responses used after a test suits run - TestLlm","doc":"Useful for showing which response fixtures were used during the test run.\n\n```sh\nTEST_LLM_SHOW_RESPONSES_HITS=1 mix test \n```","ref":"readme.html#shows-the-responses-used-after-a-test-suits-run"},{"type":"extras","title":"Shows the unused responses after a test suits run - TestLlm","doc":"```sh\nTEST_LLM_SHOW_UNUSED_RESPONSES=1 mix test\n```","ref":"readme.html#shows-the-unused-responses-after-a-test-suits-run"},{"type":"extras","title":"Removes the unused responses after a test suits run - TestLlm","doc":"Useful for cleaning up unused response fixtures which are no longer used.\n\n```sh\nTEST_LLM_SHOW_UNUSED_RESPONSES=1 mix test test \n```","ref":"readme.html#removes-the-unused-responses-after-a-test-suits-run"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}